@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2024  Johannes Pohl
+    Copyright (C) 2014-2025  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 
 // local headers
 #include "common/aixlog.hpp"
+#include "server_settings.hpp"
 
 
 using namespace std;
@@ -35,8 +36,8 @@ static constexpr auto LOG_TAG = "ControlSessionTCP";
 // https://stackoverflow.com/questions/7754695/boost-asio-async-write-how-to-not-interleaving-async-write-calls/7756894
 
 
-ControlSessionTcp::ControlSessionTcp(ControlMessageReceiver* receiver, tcp::socket&& socket)
-    : ControlSession(receiver), socket_(std::move(socket)), strand_(boost::asio::make_strand(socket_.get_executor()))
+ControlSessionTcp::ControlSessionTcp(ControlMessageReceiver* receiver, tcp::socket&& socket, const ServerSettings& settings)
+    : ControlSession(receiver, settings), socket_(std::move(socket)), strand_(boost::asio::make_strand(socket_.get_executor()))
 {
 }
 
@@ -53,7 +54,7 @@ void ControlSessionTcp::do_read()
     const std::string delimiter = "\n";
     boost::asio::async_read_until(socket_, streambuf_, delimiter,
                                   [this, self = shared_from_this(), delimiter](const std::error_code& ec, std::size_t bytes_transferred)
-                                  {
+    {
         if (ec)
         {
             LOG(ERROR, LOG_TAG) << "Error while reading from control socket: " << ec.message() << "\n";
@@ -69,9 +70,8 @@ void ControlSessionTcp::do_read()
             // LOG(DEBUG, LOG_TAG) << "received: " << line << "\n";
             if ((message_receiver_ != nullptr) && !line.empty())
             {
-                message_receiver_->onMessageReceived(shared_from_this(), line,
-                                                     [this](const std::string& response)
-                                                     {
+                message_receiver_->onMessageReceived(shared_from_this(), line, [this](const std::string& response)
+                {
                     if (!response.empty())
                         sendAsync(response);
                 });
@@ -105,9 +105,8 @@ void ControlSessionTcp::stop()
 
 void ControlSessionTcp::sendAsync(const std::string& message)
 {
-    boost::asio::post(strand_,
-                      [this, self = shared_from_this(), message]()
-                      {
+    boost::asio::post(strand_, [this, self = shared_from_this(), message]()
+    {
         messages_.emplace_back(message + "\r\n");
         if (messages_.size() > 1)
         {
@@ -120,9 +119,8 @@ void ControlSessionTcp::sendAsync(const std::string& message)
 
 void ControlSessionTcp::send_next()
 {
-    boost::asio::async_write(socket_, boost::asio::buffer(messages_.front()),
-                             [this, self = shared_from_this()](std::error_code ec, std::size_t length)
-                             {
+    boost::asio::async_write(socket_, boost::asio::buffer(messages_.front()), [this, self = shared_from_this()](std::error_code ec, std::size_t length)
+    {
         messages_.pop_front();
         if (ec)
         {
