@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,22 +16,35 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#include <iostream>
 
+// prototype/interface header file
+#include "flac_encoder.hpp"
+
+// local headers
 #include "common/aixlog.hpp"
 #include "common/snap_exception.hpp"
 #include "common/str_compat.hpp"
-#include "flac_encoder.hpp"
+
+// 3rd party headers
+#include "FLAC/metadata.h"
+
+// standard headers
+#include <iostream>
+
 
 using namespace std;
 
 namespace encoder
 {
 
+static constexpr auto LOG_TAG = "FlacEnc";
+
 FlacEncoder::FlacEncoder(const std::string& codecOptions) : Encoder(codecOptions), encoder_(nullptr), pcmBufferSize_(0), encodedSamples_(0), flacChunk_(nullptr)
 {
     headerChunk_.reset(new msg::CodecHeader("flac"));
-    pcmBuffer_ = (FLAC__int32*)malloc(pcmBufferSize_ * sizeof(FLAC__int32));
+    pcmBuffer_ = static_cast<FLAC__int32*>(malloc(pcmBufferSize_ * sizeof(FLAC__int32)));
+    metadata_[0] = nullptr;
+    metadata_[1] = nullptr;
 }
 
 
@@ -67,39 +80,56 @@ std::string FlacEncoder::name() const
 }
 
 
-void FlacEncoder::encode(const msg::PcmChunk* chunk)
+void FlacEncoder::encode(const msg::PcmChunk& chunk)
 {
     if (flacChunk_ == nullptr)
-        flacChunk_ = make_shared<msg::PcmChunk>(chunk->format, 0);
+        flacChunk_ = make_shared<msg::PcmChunk>(chunk.format, 0);
 
-    int samples = chunk->getSampleCount();
-    int frames = chunk->getFrameCount();
-    // LOG(INFO) << "payload: " << chunk->payloadSize << "\tframes: " << frames << "\tsamples: " << samples << "\tduration: " <<
-    // chunk->duration<chronos::msec>().count() << "\n";
+    int samples = chunk.getSampleCount();
+    int frames = chunk.getFrameCount();
+    // LOG(TRACE, LOG_TAG) << "payload: " << chunk.payloadSize << "\tframes: " << frames << "\tsamples: " << samples
+    //                     << "\tduration: " << chunk.duration<chronos::msec>().count() << ", format: " << chunk.format.toString() << "\n";
 
     if (pcmBufferSize_ < samples)
     {
         pcmBufferSize_ = samples;
-        pcmBuffer_ = (FLAC__int32*)realloc(pcmBuffer_, pcmBufferSize_ * sizeof(FLAC__int32));
+        pcmBuffer_ = static_cast<FLAC__int32*>(realloc(pcmBuffer_, pcmBufferSize_ * sizeof(FLAC__int32)));
     }
 
+    auto clip = [](int32_t min, int32_t max, int32_t value) -> int32_t
+    {
+        if (value < min)
+            return min;
+        if (value > max)
+            return max;
+        return value;
+    };
+
     if (sampleFormat_.sampleSize() == 1)
     {
-        FLAC__int8* buffer = (FLAC__int8*)chunk->payload;
+        auto* buffer = reinterpret_cast<FLAC__int8*>(chunk.payload);
         for (int i = 0; i < samples; i++)
-            pcmBuffer_[i] = (FLAC__int32)(buffer[i]);
+            pcmBuffer_[i] = clip(-128, 127, static_cast<FLAC__int32>(buffer[i]));
     }
     else if (sampleFormat_.sampleSize() == 2)
     {
-        FLAC__int16* buffer = (FLAC__int16*)chunk->payload;
+        auto* buffer = reinterpret_cast<FLAC__int16*>(chunk.payload);
         for (int i = 0; i < samples; i++)
-            pcmBuffer_[i] = (FLAC__int32)(buffer[i]);
+            pcmBuffer_[i] = clip(-32768, 32767, static_cast<FLAC__int32>(buffer[i]));
     }
     else if (sampleFormat_.sampleSize() == 4)
     {
-        FLAC__int32* buffer = (FLAC__int32*)chunk->payload;
-        for (int i = 0; i < samples; i++)
-            pcmBuffer_[i] = (FLAC__int32)(buffer[i]);
+        auto* buffer = reinterpret_cast<FLAC__int32*>(chunk.payload);
+        if (sampleFormat_.bits() == 24)
+        {
+            for (int i = 0; i < samples; i++)
+                pcmBuffer_[i] = clip(-8388608, 8388607, buffer[i]);
+        }
+        else
+        {
+            for (int i = 0; i < samples; i++)
+                pcmBuffer_[i] = buffer[i];
+        }
     }
 
 
@@ -108,10 +138,10 @@ void FlacEncoder::encode(const msg::PcmChunk* chunk)
     if (encodedSamples_ > 0)
     {
         double resMs = static_cast<double>(encodedSamples_) / sampleFormat_.msRate();
-        //		LOG(INFO) << "encoded: " << chunk->payloadSize << "\tframes: " << encodedSamples_ << "\tres: " << resMs << "\n";
+        //		LOG(INFO, LOG_TAG) << "encoded: " << chunk->payloadSize << "\tframes: " << encodedSamples_ << "\tres: " << resMs << "\n";
         encodedSamples_ = 0;
-        listener_->onChunkEncoded(this, flacChunk_, resMs);
-        flacChunk_ = make_shared<msg::PcmChunk>(chunk->format, 0);
+        encoded_callback_(*this, flacChunk_, resMs);
+        flacChunk_ = make_shared<msg::PcmChunk>(chunk.format, 0);
     }
 }
 
@@ -119,16 +149,16 @@ void FlacEncoder::encode(const msg::PcmChunk* chunk)
 FLAC__StreamEncoderWriteStatus FlacEncoder::write_callback(const FLAC__StreamEncoder* /*encoder*/, const FLAC__byte buffer[], size_t bytes, unsigned samples,
                                                            unsigned current_frame)
 {
-    //	LOG(INFO) << "write_callback: " << bytes << ", " << samples << ", " << current_frame << "\n";
+    //	LOG(INFO, LOG_TAG) << "write_callback: " << bytes << ", " << samples << ", " << current_frame << "\n";
     if ((current_frame == 0) && (bytes > 0) && (samples == 0))
     {
-        headerChunk_->payload = (char*)realloc(headerChunk_->payload, headerChunk_->payloadSize + bytes);
+        headerChunk_->payload = static_cast<char*>(realloc(headerChunk_->payload, headerChunk_->payloadSize + bytes));
         memcpy(headerChunk_->payload + headerChunk_->payloadSize, buffer, bytes);
         headerChunk_->payloadSize += bytes;
     }
     else
     {
-        flacChunk_->payload = (char*)realloc(flacChunk_->payload, flacChunk_->payloadSize + bytes);
+        flacChunk_->payload = static_cast<char*>(realloc(flacChunk_->payload, flacChunk_->payloadSize + bytes));
         memcpy(flacChunk_->payload + flacChunk_->payloadSize, buffer, bytes);
         flacChunk_->payloadSize += bytes;
         encodedSamples_ += samples;
@@ -141,28 +171,30 @@ namespace callback
 FLAC__StreamEncoderWriteStatus write_callback(const FLAC__StreamEncoder* encoder, const FLAC__byte buffer[], size_t bytes, unsigned samples,
                                               unsigned current_frame, void* client_data)
 {
-    FlacEncoder* flacEncoder = (FlacEncoder*)client_data;
+    auto* flacEncoder = static_cast<FlacEncoder*>(client_data);
     return flacEncoder->write_callback(encoder, buffer, bytes, samples, current_frame);
 }
 } // namespace callback
 
 void FlacEncoder::initEncoder()
 {
-    int quality(2);
+    int compression_level(2);
     try
     {
-        quality = cpt::stoi(codecOptions_);
+        compression_level = cpt::stoi(codecOptions_);
     }
     catch (...)
     {
         throw SnapException("Invalid codec option: \"" + codecOptions_ + "\"");
     }
-    if ((quality < 0) || (quality > 8))
+    if ((compression_level < 0) || (compression_level > 8))
     {
         throw SnapException("compression level has to be between 0 and 8");
     }
 
-    FLAC__bool ok = true;
+    LOG(INFO, LOG_TAG) << "Init - compression level: " << compression_level << "\n";
+
+    FLAC__bool ok = 1;
     FLAC__StreamEncoderInitStatus init_status;
     FLAC__StreamMetadata_VorbisComment_Entry entry;
 
@@ -170,33 +202,33 @@ void FlacEncoder::initEncoder()
     if ((encoder_ = FLAC__stream_encoder_new()) == nullptr)
         throw SnapException("error allocating encoder");
 
-    ok &= FLAC__stream_encoder_set_verify(encoder_, true);
+    ok &= FLAC__stream_encoder_set_verify(encoder_, 1);
     // compression levels (0-8):
     // https://xiph.org/flac/api/group__flac__stream__encoder.html#gae49cf32f5256cb47eecd33779493ac85
     // latency:
     // 0-2: 1152 frames, ~26.1224ms
     // 3-8: 4096 frames, ~92.8798ms
-    ok &= FLAC__stream_encoder_set_compression_level(encoder_, quality);
+    ok &= FLAC__stream_encoder_set_compression_level(encoder_, compression_level);
     ok &= FLAC__stream_encoder_set_channels(encoder_, sampleFormat_.channels());
     ok &= FLAC__stream_encoder_set_bits_per_sample(encoder_, sampleFormat_.bits());
     ok &= FLAC__stream_encoder_set_sample_rate(encoder_, sampleFormat_.rate());
 
-    if (!ok)
+    if (ok == 0)
         throw SnapException("error setting up encoder");
 
     // now add some metadata; we'll add some tags and a padding block
     if ((metadata_[0] = FLAC__metadata_object_new(FLAC__METADATA_TYPE_VORBIS_COMMENT)) == nullptr ||
         (metadata_[1] = FLAC__metadata_object_new(FLAC__METADATA_TYPE_PADDING)) == nullptr ||
         // there are many tag (vorbiscomment) functions but these are convenient for this particular use:
-        !FLAC__metadata_object_vorbiscomment_entry_from_name_value_pair(&entry, "TITLE", "SnapStream") ||
-        !FLAC__metadata_object_vorbiscomment_append_comment(metadata_[0], entry, false) ||
-        !FLAC__metadata_object_vorbiscomment_entry_from_name_value_pair(&entry, "VERSION", VERSION) ||
-        !FLAC__metadata_object_vorbiscomment_append_comment(metadata_[0], entry, false))
+        (FLAC__metadata_object_vorbiscomment_entry_from_name_value_pair(&entry, "TITLE", "SnapStream") == 0) ||
+        (FLAC__metadata_object_vorbiscomment_append_comment(metadata_[0], entry, 0) == 0) ||
+        (FLAC__metadata_object_vorbiscomment_entry_from_name_value_pair(&entry, "VERSION", VERSION) == 0) ||
+        (FLAC__metadata_object_vorbiscomment_append_comment(metadata_[0], entry, 0) == 0))
         throw SnapException("out of memory or tag error");
 
     metadata_[1]->length = 1234; // set the padding length
     ok = FLAC__stream_encoder_set_metadata(encoder_, metadata_, 2);
-    if (!ok)
+    if (ok == 0)
         throw SnapException("error setting meta data");
 
     // initialize encoder
