@@ -20,9 +20,11 @@
 
 
 // local headers
-#include "image_cache.hpp"
+#include "common/utils/string_utils.hpp"
 
 // standard headers
+#include <cstdint>
+#include <filesystem>
 #include <string>
 #include <vector>
 
@@ -34,25 +36,57 @@ struct ServerSettings
         int threads{-1};
         std::string pid_file{"/var/run/snapserver/pid"};
         std::string user{"snapserver"};
-        std::string group{""};
-        std::string data_dir{""};
+        std::string group;
+        std::string data_dir;
     };
 
+    struct Ssl
+    {
+        std::filesystem::path certificate;
+        std::filesystem::path certificate_key;
+        std::string key_password;
+
+        bool enabled() const
+        {
+            return !certificate.empty() && !certificate_key.empty();
+        }
+    };
+
+    struct User
+    {
+        explicit User(const std::string& user_permissions_password)
+        {
+            std::string perm;
+            name = utils::string::split_left(user_permissions_password, ':', perm);
+            perm = utils::string::split_left(perm, ':', password);
+            permissions = utils::string::split(perm, ',');
+        }
+
+        std::string name;
+        std::vector<std::string> permissions;
+        std::string password;
+    };
+
+    std::vector<User> users;
+
     struct Http
     {
         bool enabled{true};
+        bool ssl_enabled{false};
         size_t port{1780};
-        std::vector<std::string> bind_to_address{{"0.0.0.0"}};
-        std::string doc_root{""};
+        size_t ssl_port{1788};
+        std::vector<std::string> bind_to_address{{"::"}};
+        std::vector<std::string> ssl_bind_to_address{{"::"}};
+        std::string doc_root;
         std::string host{"<hostname>"};
-        inline static ImageCache image_cache;
+        std::string url_prefix;
     };
 
     struct Tcp
     {
         bool enabled{true};
         size_t port{1705};
-        std::vector<std::string> bind_to_address{{"0.0.0.0"}};
+        std::vector<std::string> bind_to_address{{"::"}};
     };
 
     struct Stream
@@ -64,7 +98,7 @@ struct ServerSettings
         std::string sampleFormat{"48000:16:2"};
         size_t streamChunkMs{20};
         bool sendAudioToMutedClients{false};
-        std::vector<std::string> bind_to_address{{"0.0.0.0"}};
+        std::vector<std::string> bind_to_address{{"::"}};
     };
 
     struct StreamingClient
@@ -74,11 +108,12 @@ struct ServerSettings
 
     struct Logging
     {
-        std::string sink{""};
+        std::string sink;
         std::string filter{"*:info"};
     };
 
     Server server;
+    Ssl ssl;
     Http http;
     Tcp tcp;
     Stream stream;
