@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2024  Johannes Pohl
+    Copyright (C) 2014-2025  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 // local headers
 #include "common/popl.hpp"
+#include <filesystem>
 #ifdef HAS_DAEMON
 #include "common/daemon.hpp"
 #endif
@@ -80,13 +81,30 @@ int main(int argc, char* argv[])
         conf.add<Implicit<string>>("", "server.group", "the group to run as when daemonized", settings.server.group, &settings.server.group);
         conf.add<Implicit<string>>("", "server.datadir", "directory where persistent data is stored", settings.server.data_dir, &settings.server.data_dir);
 
+        // SSL settings
+        conf.add<Value<std::filesystem::path>>("", "ssl.certificate", "certificate file (PEM format)", settings.ssl.certificate, &settings.ssl.certificate);
+        conf.add<Value<std::filesystem::path>>("", "ssl.certificate_key", "private key file (PEM format)", settings.ssl.certificate_key,
+                                               &settings.ssl.certificate_key);
+        conf.add<Value<string>>("", "ssl.key_password", "key password (for encrypted private key)", settings.ssl.key_password, &settings.ssl.key_password);
+
+#if 0 // feature: users
+      // Users setting
+        auto users_value = conf.add<Value<string>>("", "users.user", "<User nane>:<permissions>:<password>");
+#endif
+
         // HTTP RPC settings
         conf.add<Value<bool>>("", "http.enabled", "enable HTTP Json RPC (HTTP POST and websockets)", settings.http.enabled, &settings.http.enabled);
         conf.add<Value<size_t>>("", "http.port", "which port the server should listen on", settings.http.port, &settings.http.port);
         auto http_bind_to_address = conf.add<Value<string>>("", "http.bind_to_address", "address for the server to listen on",
                                                             settings.http.bind_to_address.front(), &settings.http.bind_to_address[0]);
+        conf.add<Value<bool>>("", "http.ssl_enabled", "enable HTTPS Json RPC (HTTPS POST and ssl websockets)", settings.http.ssl_enabled,
+                              &settings.http.ssl_enabled);
+        conf.add<Value<size_t>>("", "http.ssl_port", "which ssl port the server should listen on", settings.http.ssl_port, &settings.http.ssl_port);
+        auto http_ssl_bind_to_address = conf.add<Value<string>>("", "http.ssl_bind_to_address", "ssl address for the server to listen on",
+                                                                settings.http.ssl_bind_to_address.front(), &settings.http.ssl_bind_to_address[0]);
         conf.add<Implicit<string>>("", "http.doc_root", "serve a website from the doc_root location", settings.http.doc_root, &settings.http.doc_root);
         conf.add<Value<string>>("", "http.host", "Hostname or IP under which clients can reach this host", settings.http.host, &settings.http.host);
+        conf.add<Value<string>>("", "http.url_prefix", "URL prefix for generating album art URLs", settings.http.url_prefix, &settings.http.url_prefix);
 
         // TCP RPC settings
         conf.add<Value<bool>>("", "tcp.enabled", "enable TCP Json RPC)", settings.tcp.enabled, &settings.tcp.enabled);
@@ -143,6 +161,12 @@ int main(int argc, char* argv[])
                 for (size_t n = 0; n < http_bind_to_address->count(); ++n)
                     settings.http.bind_to_address.push_back(http_bind_to_address->value(n));
             }
+            if (http_ssl_bind_to_address->is_set())
+            {
+                settings.http.ssl_bind_to_address.clear();
+                for (size_t n = 0; n < http_ssl_bind_to_address->count(); ++n)
+                    settings.http.ssl_bind_to_address.push_back(http_ssl_bind_to_address->value(n));
+            }
             if (stream_bind_to_address->is_set())
             {
                 settings.stream.bind_to_address.clear();
@@ -152,7 +176,7 @@ int main(int argc, char* argv[])
         }
         catch (const std::invalid_argument& e)
         {
-            cerr << "Exception: " << e.what() << std::endl;
+            cerr << "Exception: " << e.what() << "\n";
             cout << "\n" << op << "\n";
             exit(EXIT_FAILURE);
         }
@@ -160,7 +184,7 @@ int main(int argc, char* argv[])
         if (versionSwitch->is_set())
         {
             cout << "snapserver v" << version::code << (!version::rev().empty() ? (" (rev " + version::rev(8) + ")") : ("")) << "\n"
-                 << "Copyright (C) 2014-2022 BadAix (snapcast@badaix.de).\n"
+                 << "Copyright (C) 2014-2025 BadAix (snapcast@badaix.de).\n"
                  << "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.\n"
                  << "This is free software: you are free to change and redistribute it.\n"
                  << "There is NO WARRANTY, to the extent permitted by law.\n\n"
@@ -189,9 +213,9 @@ int main(int argc, char* argv[])
             std::unique_ptr<encoder::Encoder> encoder(encoderFactory.createEncoder(settings.stream.codec));
             if (encoder)
             {
-                cout << "Options for codec \"" << encoder->name() << "\":\n"
+                cout << "Options for codec '" << encoder->name() << "':\n"
                      << "  " << encoder->getAvailableOptions() << "\n"
-                     << "  Default: \"" << encoder->getDefaultOptions() << "\"\n";
+                     << "  Default: '" << encoder->getDefaultOptions() << "'\n";
             }
             exit(EXIT_SUCCESS);
         }
@@ -233,8 +257,42 @@ int main(int argc, char* argv[])
         else
             throw SnapException("Invalid log sink: " + settings.logging.sink);
 
+        if (!settings.ssl.certificate.empty() && !settings.ssl.certificate_key.empty())
+        {
+            namespace fs = std::filesystem;
+            auto make_absolute = [](const fs::path& filename)
+            {
+                const fs::path cert_path = "/etc/snapserver/certs/";
+                if (filename.is_absolute())
+                    return filename;
+                if (fs::exists(filename))
+                    return fs::canonical(filename);
+                return cert_path / filename;
+            };
+            settings.ssl.certificate = make_absolute(settings.ssl.certificate);
+            if (!fs::exists(settings.ssl.certificate))
+                throw SnapException("SSL certificate file not found: " + settings.ssl.certificate.native());
+            settings.ssl.certificate_key = make_absolute(settings.ssl.certificate_key);
+            if (!fs::exists(settings.ssl.certificate_key))
+                throw SnapException("SSL certificate_key file not found: " + settings.ssl.certificate_key.native());
+        }
+        else if (settings.ssl.certificate.empty() != settings.ssl.certificate_key.empty())
+        {
+            throw SnapException("Both SSL 'certificate' and 'certificate_key' must be set or empty");
+        }
+
+        if (!settings.ssl.enabled())
+        {
+            if (settings.http.ssl_enabled)
+                throw SnapException("HTTPS enabled ([http] ssl_enabled), but no certificates specified");
+        }
+
         LOG(INFO, LOG_TAG) << "Version " << version::code << (!version::rev().empty() ? (", revision " + version::rev(8)) : ("")) << "\n";
 
+        if (settings.ssl.enabled())
+            LOG(INFO, LOG_TAG) << "SSL enabled - certificate file: '" << settings.ssl.certificate.native() << "', certificate key file: '"
+                               << settings.ssl.certificate_key.native() << "'\n";
+
         if (!streamValue->is_set() && !sourceValue->is_set())
             settings.stream.sources.push_back(sourceValue->value());
 
@@ -249,6 +307,16 @@ int main(int argc, char* argv[])
             settings.stream.sources.push_back(sourceValue->value(n));
         }
 
+#if 0 // feature: users
+        for (size_t n = 0; n < users_value->count(); ++n)
+        {
+            settings.users.emplace_back(users_value->value(n));
+            LOG(DEBUG, LOG_TAG) << "User: " << settings.users.back().name
+                                << ", permissions: " << utils::string::container_to_string(settings.users.back().permissions)
+                                << ", pw: " << settings.users.back().password << "\n";
+        }
+#endif
+
 #ifdef HAS_DAEMON
         std::unique_ptr<Daemon> daemon;
         if (daemonOption->is_set())
@@ -264,9 +332,9 @@ int main(int argc, char* argv[])
             processPriority = std::min(std::max(-20, processPriority), 19);
             if (processPriority != 0)
                 setpriority(PRIO_PROCESS, 0, processPriority);
-            LOG(NOTICE, LOG_TAG) << "daemonizing" << std::endl;
+            LOG(NOTICE, LOG_TAG) << "daemonizing" << "\n";
             daemon->daemonize();
-            LOG(NOTICE, LOG_TAG) << "daemon started" << std::endl;
+            LOG(NOTICE, LOG_TAG) << "daemon started" << "\n";
         }
         else
             Config::instance().init(settings.server.data_dir);
@@ -289,9 +357,14 @@ int main(int argc, char* argv[])
         {
             dns_services.emplace_back("_snapcast-http._tcp", settings.http.port);
         }
+        if (settings.http.ssl_enabled)
+        {
+            dns_services.emplace_back("_snapcast-https._tcp", settings.http.ssl_port);
+        }
+
         publishZeroConfg->publish(dns_services);
 #endif
-        if (settings.http.enabled)
+        if (settings.http.enabled || settings.http.ssl_enabled)
         {
             if ((settings.http.host == "<hostname>") || settings.http.host.empty())
             {
@@ -322,9 +395,8 @@ int main(int argc, char* argv[])
 
         // Construct a signal set registered for process termination.
         boost::asio::signal_set signals(io_context, SIGHUP, SIGINT, SIGTERM);
-        signals.async_wait(
-            [&io_context](const boost::system::error_code& ec, int signal)
-            {
+        signals.async_wait([&io_context](const boost::system::error_code& ec, int signal)
+        {
             if (!ec)
                 LOG(INFO, LOG_TAG) << "Received signal " << signal << ": " << strsignal(signal) << "\n";
             else
@@ -333,6 +405,7 @@ int main(int argc, char* argv[])
         });
 
         std::vector<std::thread> threads;
+        threads.reserve(settings.server.threads);
         for (int n = 0; n < settings.server.threads; ++n)
             threads.emplace_back([&] { io_context.run(); });
 
@@ -341,16 +414,16 @@ int main(int argc, char* argv[])
         for (auto& t : threads)
             t.join();
 
-        LOG(INFO, LOG_TAG) << "Stopping streamServer" << endl;
+        LOG(INFO, LOG_TAG) << "Stopping streamServer\n";
         server->stop();
-        LOG(INFO, LOG_TAG) << "done" << endl;
+        LOG(INFO, LOG_TAG) << "done\n";
     }
     catch (const std::exception& e)
     {
-        LOG(ERROR, LOG_TAG) << "Exception: " << e.what() << std::endl;
+        LOG(ERROR, LOG_TAG) << "Exception: " << e.what() << "\n";
         exitcode = EXIT_FAILURE;
     }
     Config::instance().save();
-    LOG(NOTICE, LOG_TAG) << "Snapserver terminated." << endl;
+    LOG(NOTICE, LOG_TAG) << "Snapserver terminated.\n";
     exit(exitcode);
 }
