@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2024  Johannes Pohl
+    Copyright (C) 2014-2025  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,14 +20,15 @@
 #include "pcm_stream.hpp"
 
 // local headers
-#include "base64.h"
 #include "common/aixlog.hpp"
+#include "common/base64.h"
 #include "common/error_code.hpp"
 #include "common/snap_exception.hpp"
 #include "common/str_compat.hpp"
 #include "common/utils/string_utils.hpp"
 #include "control_error.hpp"
 #include "encoder/encoder_factory.hpp"
+#include "image_cache.hpp"
 
 // 3rd party headers
 #include <boost/asio/ip/host_name.hpp>
@@ -143,14 +144,12 @@ void PcmStream::onControlRequest(const jsonrpcpp::Request& request)
 void PcmStream::pollProperties()
 {
     property_timer_.expires_after(10s);
-    property_timer_.async_wait(
-        [this](const boost::system::error_code& ec)
-        {
+    property_timer_.async_wait([this](const boost::system::error_code& ec)
+    {
         if (!ec)
         {
-            stream_ctrl_->command({++req_id_, "Plugin.Stream.Player.GetProperties"},
-                                  [this](const jsonrpcpp::Response& response)
-                                  {
+            stream_ctrl_->command({++req_id_, "Plugin.Stream.Player.GetProperties"}, [this](const jsonrpcpp::Response& response)
+            {
                 LOG(INFO, LOG_TAG) << "Response for Plugin.Stream.Player.GetProperties: " << response.to_json() << "\n";
                 if (response.error().code() == 0)
                     setProperties(response.result());
@@ -174,9 +173,8 @@ void PcmStream::onControlNotification(const jsonrpcpp::Notification& notificatio
         else if (notification.method() == "Plugin.Stream.Ready")
         {
             LOG(DEBUG, LOG_TAG) << "Plugin is ready\n";
-            stream_ctrl_->command({++req_id_, "Plugin.Stream.Player.GetProperties"},
-                                  [this](const jsonrpcpp::Response& response)
-                                  {
+            stream_ctrl_->command({++req_id_, "Plugin.Stream.Player.GetProperties"}, [this](const jsonrpcpp::Response& response)
+            {
                 LOG(INFO, LOG_TAG) << "Response for Plugin.Stream.Player.GetProperties: " << response.to_json() << "\n";
                 if (response.error().code() == 0)
                     setProperties(response.result());
@@ -230,14 +228,14 @@ void PcmStream::start()
 {
     LOG(DEBUG, LOG_TAG) << "Start: " << name_ << ", type: " << uri_.scheme << ", sampleformat: " << sampleFormat_.toString() << ", codec: " << getCodec()
                         << "\n";
-    encoder_->init([this](const encoder::Encoder& encoder, std::shared_ptr<msg::PcmChunk> chunk, double duration) { chunkEncoded(encoder, chunk, duration); },
-                   sampleFormat_);
+    encoder_->init([this](const encoder::Encoder& encoder, std::shared_ptr<msg::PcmChunk> chunk, double duration)
+    { chunkEncoded(encoder, std::move(chunk), duration); }, sampleFormat_);
 
     if (stream_ctrl_)
     {
-        stream_ctrl_->start(
-            getId(), server_settings_, [this](const jsonrpcpp::Notification& notification) { onControlNotification(notification); },
-            [this](const jsonrpcpp::Request& request) { onControlRequest(request); }, [this](std::string message) { onControlLog(std::move(message)); });
+        stream_ctrl_->start(getId(), server_settings_, [this](const jsonrpcpp::Notification& notification) {
+            onControlNotification(notification);
+        }, [this](const jsonrpcpp::Request& request) { onControlRequest(request); }, [this](std::string message) { onControlLog(std::move(message)); });
     }
 
     active_ = true;
@@ -513,9 +511,8 @@ void PcmStream::sendRequest(const std::string& method, const jsonrpcpp::Paramete
         return handler({ControlErrc::can_not_control});
 
     jsonrpcpp::Request req(++req_id_, method, params);
-    stream_ctrl_->command(req,
-                          [handler](const jsonrpcpp::Response& response)
-                          {
+    stream_ctrl_->command(req, [handler](const jsonrpcpp::Response& response)
+    {
         if (response.error().code() != 0)
             handler({static_cast<ControlErrc>(response.error().code()), response.error().data()});
         else
@@ -537,15 +534,30 @@ void PcmStream::setProperties(const Properties& properties)
     if (props.metadata.has_value() && props.metadata->art_data.has_value() && !props.metadata->art_url.has_value())
     {
         auto data = base64_decode(props.metadata->art_data->data);
-        auto md5 = ServerSettings::Http::image_cache.setImage(getName(), std::move(data), props.metadata->art_data->extension);
+        auto md5 = ImageCache::instance().setImage(getName(), std::move(data), props.metadata->art_data->extension);
 
         std::stringstream url;
-        url << "http://" << server_settings_.http.host << ":" << server_settings_.http.port << "/__image_cache?name=" << md5;
+        if (server_settings_.http.url_prefix.empty())
+        {
+            std::string proto{"http"};
+            size_t port{server_settings_.http.port};
+            if (server_settings_.http.ssl_enabled)
+            {
+                proto = "https";
+                port = server_settings_.http.ssl_port;
+            }
+            url << proto << "://" << server_settings_.http.host << ":" << port;
+        }
+        else
+        {
+            url << server_settings_.http.url_prefix;
+        }
+        url << "/__image_cache?name=" << md5;
         props.metadata->art_url = url.str();
     }
     else if (!props.metadata.has_value() || !props.metadata->art_data.has_value())
     {
-        ServerSettings::Http::image_cache.clear(getName());
+        ImageCache::instance().clear(getName());
     }
 
     if (props == properties_)
