@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,15 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef WATCH_DOG_HPP
-#define WATCH_DOG_HPP
+#pragma once
+
+
+// 3rd party headers
+#include <boost/asio/any_io_executor.hpp>
+#include <boost/asio/steady_timer.hpp>
+
+// standard headers
 
-#include <boost/asio.hpp>
-#include <memory>
 
 namespace streamreader
 {
@@ -39,7 +43,7 @@ public:
 class Watchdog
 {
 public:
-    Watchdog(boost::asio::io_context& ioc, WatchdogListener* listener = nullptr);
+    Watchdog(const boost::asio::any_io_executor& executor, WatchdogListener* listener = nullptr);
     virtual ~Watchdog();
 
     void start(const std::chrono::milliseconds& timeout);
@@ -53,5 +57,3 @@ private:
 };
 
 } // namespace streamreader
-
-#endif
